@@ -5,6 +5,8 @@
 
 G_BEGIN_DECLS
 
+#define PANEL_DRAWER_ICON "drawer"
+
 #define PANEL_DRAWER_N_LISTENERS 3
 
 typedef struct {
@@ -41,6 +43,8 @@ void  drawer_load_from_gconf       (PanelWidget   *panel_widget,
 				    gint           position,
 				    const char    *id);
 
+void  drawer_query_deletion        (Drawer *drawer);
+
 G_END_DECLS
 
 #endif
