@@ -111,6 +111,9 @@ PanelAppletBackgroundType
 						      GdkColor    *color,
 						      GdkPixmap  **pixmap);
 
+void               panel_applet_set_background_widget (PanelApplet *applet,
+						       GtkWidget   *widget);
+
 gchar             *panel_applet_get_preferences_key  (PanelApplet *applet);
 
 void               panel_applet_add_preferences      (PanelApplet  *applet,
@@ -128,6 +131,9 @@ void      	   panel_applet_set_size_hints       (PanelApplet      *applet,
 
 gboolean           panel_applet_get_locked_down      (PanelApplet  *applet);
 
+void               panel_applet_request_focus        (PanelApplet  *applet,
+						      guint32       timestamp);
+
 BonoboControl     *panel_applet_get_control          (PanelApplet  *applet);
 BonoboUIComponent *panel_applet_get_popup_component  (PanelApplet  *applet);
 
@@ -263,7 +269,6 @@ __panel_applet_shlib_factory (PortableServer_POA  poa,				\
 {										\
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);			\
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");			\
-	textdomain (GETTEXT_PACKAGE);						\
         return panel_applet_shlib_factory ((iid), (type), poa, impl_ptr,	\
 					   (callback), (data), ev);		\
 }										\
